#!/usr/bin/env bash
# ubuntu: sudo apt install bash xdg-utils golang-go adb
# Converted from run_DHO_Tools.bat by Brian K. White b.kenyon.w@gmail.com
# Original from https://www.eevblog.com/forum/testgear/hacking-the-rigol-dho800900-scope/msg5148330/#msg5148330

########################################################################
# config
#

# For DHO804, tested: RLU BW7T10
# For DHO914, probably: BODE BW15T25
options="RLU BW7T10"

scopeID=DHO8
[[ "$2" == "DHO900" ]] && scopeID=DHO9 options="BODE BW15T25"

#
########################################################################

AdbPort=55555
formatCmd=":SYSTem:OPTion:INSTall"

abrt () { echo -e "$0: $@" >&2 ; exit 1 ; }

echo "Rigol DHO800/DHO900 upgrader"
echo

# Get the IP on the IO window on the scope
IpAddress=$1
[[ ${IpAddress} ]] || ping -c 1 ${IpAddress} || {
	abrt "Usage: $0 <scope_ip_address_or_hostname>\nGet the IP from Menu->Utility>IO."
}

echo
SCPI_URL="http://${IpAddress}/scpi.html"
echo "Launching ${SCPI_URL}"
echo "After the browser pops up, move it to the side and come back to this window."
read -p "Press Enter to proceed"
open http://${IpAddress}/scpi.html

[[ -d backup ]] || mkdir backup

echo "listing attached adb devices"
adb devices
echo

echo "connecting to scope"
adb connect ${IpAddress}:${AdbPort}
echo

echo "removing old DHO800_DHO900_Update.GEL if any"
adb shell rm /rigol/DHO800_DHO900_Update.GEL
echo

echo "Building new backup DHO800_DHO900_Update.GEL"
echo "This takes about a minute..."
adb shell "cd /rigol && sh build_gel.sh"
echo

echo "downloading new backup DHO800_DHO900_Update.GEL"
adb pull rigol/DHO800_DHO900_Update.GEL backup
echo

echo "downloading Key.data"
adb pull /rigol/data/Key.data
echo

echo "Installed *.lic files before (may be none):"
adb shell ls -l /rigol/data/

echo "running rgtoolMod.go to generate SCPI commands"
go run hdo-tools-master/rgtoolMod.go Key.data ${scopeID} ${formatCmd} ${options}
echo

echo
echo "For each of the \"${formatCmd} ...\" lines above:"
echo "  o Clear out anything in the \"SPI Command: [     ]\" input field"
echo "  o Cut & past one \"${formatCmd} ...\" line"
echo "  o Hit [Send & Read]"
echo
echo "The web interface will not show anything other than echo the command back."
echo "The scope will not visibly react, but the changes should be in effect immediately without rebooting."
echo "Menu>Utility>About should show \"Max BW:100M\"."
echo "The (A)quire menu at the top of the screen, \"Mem Depth\" should have a 50M option."
echo

read -p "After doing that, press Enter"
echo 
echo "Installed *.lic files after:"
adb shell ls -l /rigol/data/

echo
echo "Finished!"


# All options listed in the firmware V1.01:
#
# OPT_AERO OPT_ARINC OPT_AUDIO OPT_AUTO OPT_BND 
# OPT_BODE OPT_BW10T20 OPT_BW15T25 OPT_BW2T4 OPT_BW2T8 OPT_BW4T8 OPT_BW7T10 OPT_BW7T15 OPT_BW7T20 
# OPT_CM_ENET OPT_CM_HDMI OPT_CM_MIPI OPT_CM_USB 
# OPT_COMP OPT_COUNT OPT_DG OPT_EMBD OPT_EYE OPT_FLEX OPT_JITTER OPT_MSO OPT_PWR OPT_RLU OPT_RTSA OPT_UNKNOWN OPT_UPA
